@@ -41,6 +41,13 @@ class MySQLDialect(Dialect):
             'database': params.get('database', 'your_database')
         }
 
+    def get_warehouse_name_and_schema(self) -> dict:
+        # In MySQL schema is synonymous with database
+        return {
+            'database_name': self.database,
+            'database_schema': self.database
+        }
+
     def safe_connection_data(self):
         return [
             self.type,
@@ -104,7 +111,7 @@ class MySQLDialect(Dialect):
     def qualify_table_name(self, table_name: str) -> str:
         return f'{table_name}'
 
-    def qualify_column_name(self, column_name: str):
+    def qualify_column_name(self, column_name: str, source_type: str = None):
         return f'{column_name}'
 
     def sql_expr_count_conditional(self, condition: str):
